@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ########################################################################################################################
 #
-# Copyright (c) 2014, Regents of the University of California
+# Copyright (c) 2020, Nifty Chips Laboratory, Hanyang University
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
@@ -42,5 +42,8 @@ from laygo2 import interface
 # Util
 from laygo2 import util
 
+# Examples
+from laygo2.examples import laygo2_tech
+
 #__all__ = ['object', 'util']
 #__all__ = ['object', 'PrimitiveUtil']
